@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Union, cast
+from typing import List, Tuple, Union, cast
 
 import keybow
 from pydantic import BaseModel, SecretStr, stricturl, validator
@@ -16,7 +16,7 @@ class KeybowSize(Enum):
     MINI = "mini"
     FULL = "full"
 
-    def get_keymap(self) -> list[tuple[int, int]]:
+    def get_keymap(self) -> List[Tuple[int, int]]:
         if self == KeybowSize.MINI:
             return keybow.MINI
         else:
@@ -32,11 +32,11 @@ HasspadHandlerConfig = Union[LightEntityHandlerConfig]
 class HasspadConfig(BaseModel):
     api: APIConfig
     size: KeybowSize
-    handlers: list[Union[None, HasspadHandlerConfig]]
+    handlers: List[Union[None, HasspadHandlerConfig]]
 
     @validator("handlers")
     def handler_count_must_match_size(
-        cls, handlers: list[HasspadHandlerConfig], values
+        cls, handlers: List[HasspadHandlerConfig], values
     ):
         size = cast(KeybowSize, values["size"])
 
